CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
78 lines
2.6 KiB
C++
78 lines
2.6 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <chrono>
|
|
#include <hip_test_common.hh>
|
|
#include <utils.hh>
|
|
|
|
namespace hipStreamDestroyTests {
|
|
|
|
HIP_TEST_CASE(Unit_hipStreamDestroy_Default) {
|
|
hipStream_t stream{};
|
|
HIP_CHECK(hipStreamCreate(&stream));
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipStreamDestroy_Negative_NullStream) {
|
|
HIP_CHECK_ERROR(hipStreamDestroy(nullptr), hipErrorInvalidResourceHandle);
|
|
}
|
|
|
|
template <size_t numDataPoints> void checkDataSet(int* deviceData) {
|
|
HIP_CHECK(hipStreamSynchronize(nullptr));
|
|
std::array<int, numDataPoints> hostData{};
|
|
HIP_CHECK(
|
|
hipMemcpy(hostData.data(), deviceData, sizeof(int) * numDataPoints, hipMemcpyDeviceToHost));
|
|
REQUIRE(std::all_of(std::begin(hostData), std::end(hostData), [](int x) { return x == 1; }));
|
|
}
|
|
|
|
__global__ void setToOne(int* x, size_t size) {
|
|
unsigned int idx = blockIdx.x * blockDim.x + threadIdx.x;
|
|
if (idx < size) {
|
|
x[idx] = 1;
|
|
}
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipStreamDestroy_WithFinishedWork) {
|
|
hipStream_t stream{};
|
|
HIP_CHECK(hipStreamCreate(&stream));
|
|
|
|
constexpr int numDataPoints = 10;
|
|
int* deviceData{};
|
|
HIP_CHECK(hipMalloc(&deviceData, sizeof(int) * numDataPoints));
|
|
HIP_CHECK(hipMemset(deviceData, 0, sizeof(int) * numDataPoints));
|
|
|
|
setToOne<<<1, numDataPoints, 0, stream>>>(deviceData, numDataPoints);
|
|
checkDataSet<numDataPoints>(deviceData);
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
HIP_CHECK(hipFree(deviceData));
|
|
}
|
|
|
|
// hipStreamDestroy should return immediately then clean up the resources when the stream is empty
|
|
// of work
|
|
#if HT_AMD /* Disabled because frequency based wait is timing out on nvidia platforms */
|
|
HIP_TEST_CASE(Unit_hipStreamDestroy_WithPendingWork) {
|
|
hipStream_t stream{};
|
|
HIP_CHECK(hipStreamCreate(&stream));
|
|
constexpr int numDataPoints = 10;
|
|
int* deviceData{};
|
|
HIP_CHECK(hipMalloc(&deviceData, sizeof(int) * numDataPoints));
|
|
HIP_CHECK(hipMemset(deviceData, 0, sizeof(int) * numDataPoints));
|
|
|
|
LaunchDelayKernel(std::chrono::milliseconds(isQuickLevel() ? 50 : 500), stream);
|
|
setToOne<<<1, numDataPoints, 0, stream>>>(deviceData, numDataPoints);
|
|
SECTION("Without stream query") { fprintf(stderr, "Without stream query\n"); }
|
|
SECTION("With stream query") {
|
|
fprintf(stderr, "With stream query\n");
|
|
HIP_CHECK_ERROR(hipStreamQuery(stream), hipErrorNotReady);
|
|
HIP_CHECK_ERROR(hipStreamQuery(nullptr), hipErrorNotReady);
|
|
}
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
checkDataSet<numDataPoints>(deviceData);
|
|
HIP_CHECK(hipFree(deviceData));
|
|
}
|
|
#endif
|
|
} // namespace hipStreamDestroyTests
|